@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
 require "monitor"
-require "rubygems"
-require "rubygems/config_file"
 
 module Bundler
   class RubygemsIntegration
@@ -514,6 +512,15 @@ module Bundler
         h
       end
 
+      Bundler.rubygems.default_stubs.each do |stub|
+        default_spec = stub.to_spec
+        default_spec_name = default_spec.name
+        next if specs_by_name.key?(default_spec_name)
+
+        specs << default_spec
+        specs_by_name[default_spec_name] = default_spec
+      end
+
       replace_gem(specs, specs_by_name)
       stub_rubygems(specs)
       replace_bin_path(specs, specs_by_name)
@@ -850,6 +857,16 @@ module Bundler
         end
       end
 
+      if Gem::Specification.respond_to?(:default_stubs)
+        def default_stubs
+          Gem::Specification.default_stubs("*.gemspec")
+        end
+      else
+        def default_stubs
+          Gem::Specification.send(:default_stubs, "*.gemspec")
+        end
+      end
+
       def use_gemdeps(gemfile)
         ENV["BUNDLE_GEMFILE"] ||= File.expand_path(gemfile)
         require "bundler/gemdeps"
