@@ -3,6 +3,7 @@
 require "bundler/compatibility_guard"
 
 require "pathname"
+require "rbconfig"
 require "rubygems"
 
 require "bundler/version"
@@ -140,12 +141,13 @@ module Bundler
     end
 
     def major_deprecation(major_version, message)
-      if Bundler.bundler_major_version >= major_version
+      bundler_major_version = Bundler.bundler_major_version
+      if bundler_major_version > major_version
         require "bundler/errors"
-        raise DeprecatedError, "[REMOVED FROM #{major_version}.0] #{message}"
+        raise DeprecatedError, "[REMOVED FROM #{major_version.succ}.0] #{message}"
       end
 
-      return unless prints_major_deprecations?
+      return unless bundler_major_version >= major_version || prints_major_deprecations?
       @major_deprecation_ui ||= Bundler::UI::Shell.new("no-color" => true)
       ui = Bundler.ui.is_a?(@major_deprecation_ui.class) ? Bundler.ui : @major_deprecation_ui
       ui.warn("[DEPRECATED FOR #{major_version}.0] #{message}")
@@ -276,7 +278,7 @@ module Bundler
           # avoid stepping above the tmp directory when testing
           gemspec = if ENV["BUNDLE_RUBY"] && ENV["BUNDLE_GEM"]
             # for Ruby Core
-            "lib/bundler.gemspec"
+            "lib/bundler/bundler.gemspec"
           else
             "bundler.gemspec"
           end
@@ -340,7 +342,7 @@ module Bundler
 
     def set_rubylib
       rubylib = (ENV["RUBYLIB"] || "").split(File::PATH_SEPARATOR)
-      rubylib.unshift bundler_ruby_lib
+      rubylib.unshift bundler_ruby_lib unless RbConfig::CONFIG["rubylibdir"] == bundler_ruby_lib
       Bundler::SharedHelpers.set_env "RUBYLIB", rubylib.uniq.join(File::PATH_SEPARATOR)
     end
 
